@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # -*- coding: UTF-8 -*-
 '''
     magento API
@@ -7,7 +6,7 @@
     :copyright: (c) 2010 by Openlabs Technologies & Consulting (P) LTD
     :license: AGPLv3, see LICENSE for more details
 '''
-__version__ = '0.1.1'
+__version__ = '0.1.4'
 
 __all__ = [
             'API',
@@ -15,7 +14,8 @@ __all__ = [
             'Country', 'Region',
             'Category', 'CategoryAttribute', 'Product', 'ProductAttribute',
             'ProductAttributeSet', 'ProductTypes', 'ProductImages',
-            'ProductTierPrice', 'ProductLinks', 'Inventory'
+            'ProductTierPrice', 'ProductLinks', 'Inventory',
+            'Order', 'Shipment', 'Invoice',
             ]
 
 from api import API
@@ -25,3 +25,4 @@ from catalog import Category, CategoryAttribute
 from catalog import Product, ProductAttribute, ProductAttributeSet
 from catalog import ProductTypes, ProductImages, ProductTierPrice
 from catalog import ProductLinks, Inventory
+from sales import Order, Shipment, Invoice
